@@ -108,6 +108,7 @@ class TestFunctional(unittest.TestCase):
                 self.conn.delete_container(container)
             except swiftclient.ClientException:
                 pass
+        self.conn.close()
 
     def _check_account_headers(self, headers):
         headers_to_check = [
@@ -153,6 +154,18 @@ class TestFunctional(unittest.TestCase):
         self.assertTrue(len(containers) >= 1)
         self.assertEqual(self.containername_2, containers[0].get('name'))
 
+        # Test prefix
+        _, containers = self.conn.get_account(prefix='dne')
+        self.assertEqual(0, len(containers))
+
+        # Test delimiter
+        _, containers = self.conn.get_account(
+            prefix=self.containername, delimiter='_')
+        self.assertEqual(2, len(containers))
+        self.assertEqual(self.containername, containers[0].get('name'))
+        self.assertTrue(
+            self.containername_2.startswith(containers[1].get('subdir')))
+
     def _check_container_headers(self, headers):
         self.assertTrue(headers.get('content-length'))
         self.assertTrue(headers.get('x-container-object-count'))
@@ -485,9 +498,6 @@ class TestUsingKeystone(TestFunctional):
             self.auth_url, username, password, auth_version=self.auth_version,
             os_options=os_options)
 
-    def setUp(self):
-        super(TestUsingKeystone, self).setUp()
-
 
 class TestUsingKeystoneV3(TestFunctional):
     """
@@ -514,6 +524,3 @@ class TestUsingKeystoneV3(TestFunctional):
         return swiftclient.Connection(self.auth_url, username, password,
                                       auth_version=self.auth_version,
                                       os_options=os_options)
-
-    def setUp(self):
-        super(TestUsingKeystoneV3, self).setUp()
